@@ -22,6 +22,9 @@ data are binhex-encoded.  Common non-standard MIME encodings for this:
     x-uu
     x-uuencode
 
+=head1 SEE ALSO
+
+L<MIME::Decoder>
 
 =head1 AUTHOR
 
@@ -42,7 +45,7 @@ use Convert::BinHex;
 @ISA = qw(MIME::Decoder);
 
 # The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.426";
+$VERSION = "5.428";
 
 
 #------------------------------
