@@ -25,6 +25,10 @@ read-and-write fixed-size chunks.
 Both the B<encoder> and B<decoder> do a simple pass-through of the data
 from input to output.
 
+=head1 SEE ALSO
+
+L<MIME::Decoder>
+
 
 =head1 AUTHOR
 
@@ -41,7 +45,7 @@ use vars qw(@ISA $VERSION);
 @ISA = qw(MIME::Decoder);
 
 ### The package version, both in 1.23 style *and* usable by MakeMaker:
-$VERSION = "5.426";
+$VERSION = "5.428";
 
 ### Buffer length:
 my $BUFLEN = 8192;
